import java.io.File;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellValue;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.FormulaEvaluator;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.usermodel.WorkbookFactory;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.ss.util.NumberToTextConverter;

public class Bug {

	private final Sheet sheet;
	private final FormulaEvaluator evaluator;

	public static void main(String[] args) throws Exception {
		Bug bug = new Bug();

		double a1 = bug.getNumeric("A1");
		System.out.println("A1 numeric: " + a1);

		double numeric = bug.getNumeric("A3");
		System.out.println("A3 numeric: " + numeric);

		String text = NumberToTextConverter.toText(numeric);
		System.out.println("A3 text: " + text);

		String formatted = bug.getFormatted("A3");
		System.out.println("A3 formatted: " + formatted);

		String concatenated = bug.getString("A4");
		System.out.println("A4 concatenated: " + concatenated);

	}

	public Bug() throws Exception {
		Workbook wb = WorkbookFactory.create(new File("bug.xlsx"));
		sheet = wb.getSheetAt(0);
		evaluator = wb.getCreationHelper().createFormulaEvaluator();
	}

	private String getFormatted(String cellName) {
		Cell cell = getCell(cellName);
		DataFormatter f = new DataFormatter();
		return f.formatCellValue(cell, evaluator);
	}

	private double getNumeric(String cellName) {
		Cell cell = getCell(cellName);
		CellValue cellValue = evaluator.evaluate(cell);
		return cellValue.getNumberValue();
	}

	private String getString(String cellName) {
		Cell cell = getCell(cellName);
		CellValue cellValue = evaluator.evaluate(cell);
		return cellValue.getStringValue();
	}

	private Cell getCell(String celle) {
		CellReference cellReference = new CellReference(celle);
		Row row = sheet.getRow(cellReference.getRow());
		return row.getCell(cellReference.getCol());
	}

}
